@@ -8,7 +8,7 @@ class Arirang
 
     def baedal
         ari_title  = "http server allow check\n"
-        ari_desc   = "-G option to arirang ruby script\n"
+        ari_desc   = "-O option to arirang ruby script\n"
         ari_author = "pilot <pilot@monkey.org>\n"
 
         puts "title: #{ari_title}"
@@ -18,14 +18,15 @@ class Arirang
 
     def asadal
         ariconnect
-        buf = "OPTIONS / HTTP/1.0\n\n"
+        buf = "OPTIONS / HTTP/1.0\r\n\r\n"
         resp = arisend(buf)
 
         # buf = $ari_recv.split("\r\n")[0..10].join("\r\n")
         resp.each do |line|
         x = line.match(/^Allow\: (.+)/)
             if x != nil
-                puts "#{$ari_host} - #{x[1]}"
+                y = "#{$ari_host} - #{$ari_sport}/tcp - #{x[1]}\n"
+                ariprint(y)
             end
 
         end
