@@ -17,7 +17,7 @@ class Arirang
 
      def asadal
          ariconnect
-         extra = "GET / HTTP/1.0\n\n"
+         extra = "GET / HTTP/1.0\r\n\r\n"
          response = arisend(extra)
          response.each do |line|
          x = line.match(/^Server\: (.+)\r/)
