@@ -1,4 +1,4 @@
-# arirang ruby script example
+# arirang script example
 
 
 class Arirang
@@ -20,7 +20,7 @@ class Arirang
     end
 
     def asadal
-        buf =  "GET / HTTP/1.0\n\n"
+        buf =  "GET / HTTP/1.0\r\n\r\n"
         ariconnect
         res = arisend(buf)
 
@@ -30,7 +30,8 @@ class Arirang
             if x != nil
             if x[1] > "0.6.0" and x[1] < "0.6.39" and x[1] != nil
                 $y = x[1].gsub(/\r\n/,"") 
-                puts "#{$ari_host} - nginx running with " + "#{$y} - oveflow version CVE-2009-2629"  
+                z = "#{$ari_host} - nginx running with " + "#{$y} - overflow version CVE-2009-2629\n"  
+                ariprint(z)
             end
             end
         end 
