@@ -16,9 +16,10 @@ class Arirang
 
      def asadal
          ariconnect
-         buf = "CONNECT www.google.com:80 HTTP/1.0\n\n"
+         buf = "CONNECT www.google.com:80 HTTP/1.0\r\n\r\n"
          response = arisend(buf)
-         puts "#{$ari_host} - " + response
+         z = "#{$ari_host} - " + response
+		 ariprint(z)
      end
 
 
