@@ -16,13 +16,14 @@ class Arirang
 
      def asadal
          ariconnect
-         buf = "GET /robots.txt HTTP/1.0\n\n"
+         buf = "GET /robots.txt HTTP/1.0\r\n\r\n"
          response = arisend(buf)
          response.each do |line|
-        	if line =~ /200 OK*/
-            puts "#{$ari_host} - robots.txt found ^_^;;"
-        	end
-    	 end
+            if line =~ /200 OK*/
+                z = "#{$ari_host} - robots.txt found ^_^;; \n"
+                ariprint(z)
+            end
+         end
 
      end
 
