@@ -17,12 +17,13 @@ class Arirang
      end
 
      def asadal
-         buf = "GET /" + "a" * 2048 + " HTTP/1.0\n\n"
+         buf = "GET /" + "a" * 2048 + " HTTP/1.0\r\n\r\n"
          ariconnect
          response = arisend(buf)
          response.each do |line|
             if line =~ /500*/
-                puts "#{$ari_host} - 500 Server Error Reponse"
+                y = "#{$ari_host} - 500 Server Error Reponse\n"
+                ariprint(y)
             end
          end
     end
