@@ -22,8 +22,8 @@ class Arirang
          response.each do |line|
            x = line.match(/^SSH-(.+)/)
              if x != nil
-              y = "#{$ari_host} - #{x[1]}"
-              puts y
+              y = "#{$ari_host} - #{$ari_sport}/tcp - #{x[1]}\n"    
+              ariprint(y)
           end
         end
      end
